Visualization for the CASA package
==================================

This package includes the visualization elements of the CASA package for
processing data collected from radio telescopes. More information about CASA
can be found on the `CASA home page <https://casa.nrao.edu/>`_.

cubevis is based on `Bokeh <https://bokeh.org/>`_. It provides visualization
elements for three different interaction settings:

* Python command line with display to a web browser
* Jupyter notebook
* `Electron <https://www.electronjs.org/>`_ app

However not all elements support all interaction settings.

